==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/es.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidad",
    "-" : "-",
    "Add external admin" : "Añadir administrador externo",
    "Your files are not protected by encryption." : "Tus archivos no están protegidos por la encriptación.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Tus archivos están encriptados con {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protegido con cifrado de disco completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Tus archivos están encriptados por {linkopen}server-side-encryption ↗{linkclose}. Además, este servidor está protegido con cifrado de disco completo.",
    "This server is using full-disk-encryption." : "Este servidor está usando cifrado de disco completo.",
    "Your data is located in: " : "Tus datos se encuentran en: ",
    "The admin hasn't selected the location of the server yet." : "Los administradores no han seleccionado todavía la localización del servidor.",
    "Please select a country" : "Por favor, selecciona un país",
    "You don't have any shares with individual users." : "No tienes recursos compartidos con usuarios individuales.",
    "Somaliland" : "Somalilandia",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbaiyán",
    "Bosnia and Herzegowina" : "Bosnia y Herzegovina",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Brunei" : "Brunéi",
    "Bolivia" : "Bolivia",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Democratic Republic of the Congo" : "República Democrática del Congo",
    "Central African Republic" : "República Centroafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suiza",
    "Cote d'Ivoire" : "Costa de Marfil",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cyprus" : "Chipre",
    "Czech" : "Chequia",
    "Germany" : "Alemania",
    "Djibouti" : "Yibuti",
    "Denmark" : "DInamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Argelia",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipto",
    "West Sahara" : "Sáhara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fiyi",
    "Falkland Islands" : "Islas Malvinas",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom" : "Reino Unido",
    "Georgia" : "Georgia",
    "Ghana" : "Gana",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinea Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Croatia" : "Croacia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "India" : "India",
    "Iraq" : "Iraq",
    "Iran" : "Irán",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordania",
    "Japan" : "Japón",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirguizistán",
    "Cambodia" : "Camboya",
    "North Korea" : "Corea del Norte",
    "South Korea" : "Corea del Sur",
    "Kuwait" : "Kuwait",
    "Kazakhstan" : "Kazajistán",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marruecos",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagascar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauritania",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nueva Caledonia",
    "Niger" : "Níger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Bajos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nueva Zelanda",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "Papua New Guinea" : "Papúa Nueva Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Pakistán",
    "Poland" : "Polonia",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Catar",
    "Romania" : "Rumanía",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudí",
    "Solomon Islands" : "Islas Salomón",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Slovenia" : "Eslovenia",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Sierra Leona",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudán del Sur",
    "El Salvador" : "El Salvador",
    "Syria" : "Siria",
    "Swaziland" : "Suazilandia",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Tierras Australes y Antárticas Francesas",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tayikistán",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistán",
    "Tunisia" : "Túnez",
    "Turkey" : "Turquía",
    "Trinidad and Tobago" : "Trinidad y Tobago",
    "Taiwan" : "Taiwán",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucrania",
    "Uganda" : "Uganda",
    "United States" : "Estados Unidos",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistán",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Yemen",
    "South Africa" : "Sudáfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabue",
    "Your Nextcloud account" : "Tu cuenta de Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Tus datos representan quien eres y pueden ser robados fácilmente. En Nextcloud creemos que tienes derecho a decidir que pasa con tus datos. Nextcloud protege tus derechos como esta definido en el Manifiesto de los Datos del Usuario.",
    "User Data Manifesto 2.0" : "Manifiesto de Datos de Usuario 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definiendo los derechos básicos para que las personas controlen sus propios datos en la era de internet.",
    "Control" : "Control",
    "over user data access" : "sobre el acceso a datos de usuario",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Los datos explícita y voluntariamente subidos por un usuario deberían estar bajo el control definitivo del usuario. Los usuarios deberían poder decidir a quién otorgar acceso a sus dato sy con qué permisos y licencias se debería conceder tal acceso.",
    "Knowledge" : "Conocimiento",
    "of how the data is stored" : "de cómo se almacenan los datos",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Cuando los datos se suben a un proveedor de servicio específico, los usuarios deberían ser informados sobre dónde almacen los datos ese proveedor, durante cuánto tiempo, en que jurisdicción opera y qué leyes son aplicables.",
    "Freedom" : "Libertad",
    "to choose a platform" : "para elegir una plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Los usuarios siempre deberían poder extraer sus datos del servicio en cualquier momento sin experimentar ningún cierra del vendedor. Los estándares abiertos para formatos y protocolos son necesarios para esto.",
    "Learn more ↗" : "Saber más ↗",
    "Where is your data?" : "¿Dónde están tus datos?",
    "Who has access to your data?" : "¿Quién tiene acceso a tus datos?",
    "Administrators" : "Administradores",
    "People you shared with" : "Gente con la que los has compartido",
    "Privacy policy" : "Política de privacidad",
    "Read the privacy policy." : "Leer la política de privacidad.",
    "Encryption" : "Cifrado"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/privacy/l10n/es.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privacidad",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "El centro de privacidad muestra dónde están almacenados sus datos y quién puede acceder a ellos, debido a que los haya compartido o porque sean administradores del sistema.",
    "Remove external admin" : "Quitar administrador externo",
    "Add external admin" : "Añadir administrador externo",
    "Name of external admin" : "Nombre del administrador externo",
    "This server is using full-disk-encryption." : "Este servidor está usando cifrado de disco completo.",
    "Your files are not protected by encryption." : "Tus archivos no están protegidos por la encriptación.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Tus archivos están encriptados con {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Este servidor está protegido con cifrado de disco completo.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Tus archivos están encriptados por {linkopen}server-side-encryption ↗{linkclose}. Además, este servidor está protegido con cifrado de disco completo.",
    "Your data is located in: " : "Tus datos se encuentran en: ",
    "The admin hasn't selected the location of the server yet." : "Los administradores no han seleccionado todavía la localización del servidor.",
    "Change data location" : "Cambiar localización de los datos",
    "Please select a region" : "Por favor, selecciona una región",
    "You don't have any shares with individual users." : "No tienes recursos compartidos con usuarios individuales.",
    "Somaliland" : "Somalilandia",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Antigua and Barbuda" : "Antigua y Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antártida",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Estadounidense",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Islas Åland",
    "Azerbaijan" : "Azerbaiyán",
    "Bosnia and Herzegovina" : "Bosnia y Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Baréin",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "San Bartolomé",
    "Bermuda" : "Bermudas",
    "Brunei" : "Brunéi",
    "Bolivia" : "Bolivia",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustaquio y Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Bouvet Island" : "Isla Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Islas Cocos (Keeling)",
    "Democratic Republic of the Congo" : "República Democrática del Congo",
    "Central African Republic" : "República Centroafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suiza",
    "Cote d'Ivoire" : "Costa de Marfil",
    "Cook Islands" : "Islas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curazao",
    "Christmas Island" : "Isla de Navidad",
    "Cyprus" : "Chipre",
    "Czech" : "Chequia",
    "Germany" : "Alemania",
    "Djibouti" : "Yibuti",
    "Denmark" : "DInamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Argelia",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipto",
    "West Sahara" : "Sáhara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fiyi",
    "Falkland Islands" : "Islas Malvinas",
    "Micronesia" : "Micronesia",
    "Faroe Islands" : "Islas Faroe",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom" : "Reino Unido",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guyana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Islas Georgias del Sur y Sandwich del Sur",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea Bissau",
    "Guyana" : "Guyana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Isla Heard e Islas McDonald",
    "Croatia" : "Croacia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Isla de Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Británico del Océano Índico",
    "Iraq" : "Iraq",
    "Iran" : "Irán",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordania",
    "Japan" : "Japón",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirguizistán",
    "Cambodia" : "Camboya",
    "Kiribati" : "Kiribati",
    "Comores" : "Comoras",
    "Saint Kitts and Nevis" : "Saint Kitts y Nevis",
    "North Korea" : "Corea del Norte",
    "South Korea" : "Corea del Sur",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Islas Caimán",
    "Kazakhstan" : "Kazajistán",
    "Laos" : "Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lucía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marruecos",
    "Monaco" : "Mónaco",
    "Moldova" : "Moldavia",
    "Montenegro" : "Montenegro",
    "Saint Martin" : "San Martín",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Islas Marshall",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Islas Marianas del Norte",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricio",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nueva Caledonia",
    "Niger" : "Níger",
    "Norfolk Island" : "Isla Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Bajos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nueva Zelanda",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "French Polynesia" : "Polinesia Francesa",
    "Papua New Guinea" : "Papúa Nueva Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Pakistán",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "Saint Pierre y Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Catar",
    "Réunion" : "Reunión",
    "Romania" : "Rumanía",
    "Serbia" : "Serbia",
    "Russia" : "Rusia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudí",
    "Solomon Islands" : "Islas Salomón",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Helena, Ascensión y Tristán de Acuña",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard y Jan Mayen",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Sierra Leona",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudán del Sur",
    "Sao Tome and Principe" : "Santo Tomé y Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten" : "San Martín holandés",
    "Syria" : "Siria",
    "Swaziland" : "Suazilandia",
    "Turks and Caicos Islands" : "Islas Turcos y Caicos",
    "Chad" : "Chad",
    "Fr. S. Antarctic Lands" : "Tierras Australes y Antárticas Francesas",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tayikistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistán",
    "Tunisia" : "Túnez",
    "Tonga" : "Tonga",
    "Turkey" : "Turquía",
    "Trinidad and Tobago" : "Trinidad y Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwán",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ucrania",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Islas Ultramarinas Menores Estadounidenses",
    "United States" : "Estados Unidos",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistán",
    "Holy See" : "Estado Vaticano",
    "Saint Vincent and the Grenadines" : "San Vicente y Granadinas",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Islas Vírgenes (británicas)",
    "Virgin Islands (U.S.)" : "Islas Vírgenes (estadounidenses)",
    "Vietnam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis y Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudáfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabue",
    "Your Nextcloud account" : "Tu cuenta de Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Tus datos representan quien eres y pueden ser robados fácilmente. En Nextcloud creemos que tienes derecho a decidir que pasa con tus datos. Nextcloud protege tus derechos como esta definido en el Manifiesto de los Datos del Usuario.",
    "User Data Manifesto 2.0" : "Manifiesto de Datos de Usuario 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Definiendo los derechos básicos para que las personas controlen sus propios datos en la era de internet.",
    "Control" : "Control",
    "over user data access" : "sobre el acceso a datos de usuario",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Los datos explícita y voluntariamente subidos por un usuario deberían estar bajo el control definitivo del usuario. Los usuarios deberían poder decidir a quién otorgar acceso a sus dato sy con qué permisos y licencias se debería conceder tal acceso.",
    "Knowledge" : "Conocimiento",
    "of how the data is stored" : "de cómo se almacenan los datos",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Cuando los datos se suben a un proveedor de servicio específico, los usuarios deberían ser informados sobre dónde almacen los datos ese proveedor, durante cuánto tiempo, en que jurisdicción opera y qué leyes son aplicables.",
    "Freedom" : "Libertad",
    "to choose a platform" : "para elegir una plataforma",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Los usuarios siempre deberían poder extraer sus datos del servicio en cualquier momento sin experimentar ningún cierra del vendedor. Los estándares abiertos para formatos y protocolos son necesarios para esto.",
    "Learn more ↗" : "Saber más ↗",
    "Where is your data?" : "¿Dónde están tus datos?",
    "Who has access to your data?" : "¿Quién tiene acceso a tus datos?",
    "Administrators" : "Administradores",
    "People you shared with" : "Gente con la que los has compartido",
    "Privacy policy" : "Política de privacidad",
    "Read the privacy policy." : "Leer la política de privacidad.",
    "Encryption" : "Cifrado",
    "Please select a country" : "Por favor, selecciona un país",
    "Bosnia and Herzegowina" : "Bosnia y Herzegovina"
},
"nplurals=2; plural=(n != 1);");
